Module: Twi::Config
- Included in:
- Twi
- Defined in:
- lib/twi/config.rb
Overview
Provides methods to read and write global configuration settings.
A typical usage is to set the sid and secret to interact with Twilio API.
Note that Twi.configure has precedence over values through with environment variables (see Lio).
Instance Method Summary collapse
-
#configure {|Twi::Lio| ... } ⇒ Object
Yields the global configuration to the given block.
-
#lio ⇒ Twi::Lio
The global configuration.
Instance Method Details
#configure {|Twi::Lio| ... } ⇒ Object
Yields the global configuration to the given block.
25 26 27 |
# File 'lib/twi/config.rb', line 25 def configure yield lio if block_given? end |